#!/usr/bin/python

import setup

setup.pre_install()
from charmhelpers.core.hookenv import Hooks, UnregisteredHookError, log, relation_get, related_units, charm_dir, \
  status_set, config
from charmhelpers.core.host import service_restart, service_stop, service_start
from charmhelpers.core.templating import render
import os
import sys
import subprocess

hooks = Hooks()


@hooks.hook('start')
def start():
  service_send('start')

@hooks.hook('stop')
def stop():
  service_send('stop')

def restart():
  service_send('restart')

@hooks.hook('config-changed')
def config_changed():
  if config('influx_host') != '':
    influx = {
      'host': config('influx_host'),
      'port': config('influx_port'),
      'user': config('influx_user'),
      'password': config('influx_password'),
    }
    setup_influx(influx)
    restart()

def service_send(action):
  try:
    subprocess.check_call(['service', 'telegraf', action])
  except subprocess.CalledProcessError as err:
    log('Service telegraf {} failed with return code: {}'.format(action, err.returncode),
      level='ERROR')

@hooks.hook('db-api-relation-changed')
def db_api_relation_changed():
  host = relation_get('hostname')
  port = relation_get('port')
  user = relation_get('user')
  password = relation_get('password')
  if (host == None or port == None or user == None or password == None):
    log("Do not have the configuration for InfluxDB")
    exit
  influx = {
    'host': host,
    'port': port,
    'user': user,
    'password': password,
  }
  log("Setting up influx config")
  setup_influx(influx)
  log("Setup config, restarting")
  restart()

def setup_influx(influx):
  log("Setting up telegraf.conf with {}".format(influx))
  render(source='telegraf.conf',
         target='/etc/opt/telegraf/telegraf.conf',
         owner='root',
         perms=0o775,
         context={
             'influx': influx,
         })

if __name__ == '__main__':
  try:
      hooks.execute(sys.argv)
      status_set('active', '')
  except UnregisteredHookError as e:
      log('Unknown hook {} - skipping.'.format(e))