#!/usr/bin/python3
import os
import sys
import time
import json

import amulet
import requests

seconds = 20000

d = amulet.Deployment(series='trusty')

d.add('telegraf')
# d.add('lp:~chris.macnaughton/charms/trusty/influxdb')
# d.add('cs:~chris.macnaughton/trusty/influxdb')
d.add('influxdb', charm='lp:~chris.macnaughton/charms/trusty/influxdb/trunk')

d.relate('influxdb:api', 'telegraf:db-api')
d.relate('influxdb:juju-info', 'telegraf:juju-info')

try:
    d.setup(timeout=seconds)
except amulet.helpers.TimeoutError:
    amulet.raise_status(amulet.SKIP, msg="Environment wasn't stood up in time")
except:
    raise


##
# Set relationship aliases
##
telegraf_unit = d.sentry.unit['telegraf/0']
influxdb_unit = d.sentry.unit['influxdb/0']

def test_index_created():
    url = 'http://%s:8086/query?q=show databases' % influxdb_unit.info['public-address']
    r = requests.get(url)
    if not r.ok:
        amulet.raise_status(amulet.FAIL,
                            msg="Error performing query.")
    try:
        result = r.json()

        if ['telegraf'] not in result['results'][0]['series'][0]['values']:
            amulet.raise_status(amulet.FAIL,
                                msg="Telegraf failed to setup corerct index.")
    except ValueError:
        exc_type, value, traceback = sys.exc_info()
        exc_text = "Exception: (%s) %s. %s" % (value, exc_type, traceback)
        amulet.raise_status(amulet.FAIL,
                            msg="Value returned not a valid json." + r.text +
                            exc_text)
def test_data_indexed():
    url = 'http://%s:8086/query?db=telegraf&q=select count(value) as count from disk_free' % influxdb_unit.info['public-address']
    r = requests.get(url)
    if not r.ok:
        amulet.raise_status(amulet.FAIL,
                            msg="Error performing query.")
    try:
        result = r.json()
        print(result)
        if result['results'][0]['series'][0]['values'][0][1] == 0:
            amulet.raise_status(amulet.FAIL,
                                msg="Telegraf failed to send data.")
    except ValueError:
        exc_type, value, traceback = sys.exc_info()
        exc_text = "Exception: (%s) %s. %s" % (value, exc_type, traceback)
        amulet.raise_status(amulet.FAIL,
                            msg="Value returned not a valid json." + r.text +
                            exc_text)
def test_web_interface():
    time.sleep(3)

    test_index_created()
    test_data_indexed()



test_web_interface()
